@@ -4,6 +4,9 @@ const esYmlTmpl = `
 cluster:
   name: ${CLUSTER_NAME}
 
+bootstrap:
+  system_call_filter: {{.SystemCallFilter}}
+
 script:
   inline: true
   stored: true
@@ -42,6 +45,9 @@ openshift.searchguard:
 
 openshift.kibana.index.mode: {{.KibanaIndexMode}}
 
+prometheus:
+  indices: false
+
 path:
   data: /elasticsearch/persistent/${CLUSTER_NAME}/data
   logs: /elasticsearch/persistent/${CLUSTER_NAME}/logs
