@@ -41,10 +41,12 @@ func (elasticsearchRequest *ElasticsearchRequest) UpdateClusterStatus() error {
 	switch {
 	case allocation == "none":
 		clusterStatus.ShardAllocationEnabled = api.ShardAllocationNone
-	case err != nil:
-		clusterStatus.ShardAllocationEnabled = api.ShardAllocationUnknown
-	default:
+	case allocation == "primaries":
+		clusterStatus.ShardAllocationEnabled = api.ShardAllocationPrimaries
+	case allocation == "all":
 		clusterStatus.ShardAllocationEnabled = api.ShardAllocationAll
+	default:
+		clusterStatus.ShardAllocationEnabled = api.ShardAllocationUnknown
 	}
 
 	clusterStatus.Pods = rolePodStateMap(cluster.Namespace, cluster.Name, elasticsearchRequest.client)
